@@ -1,17 +1,18 @@
 import speech_recognition as sr
 import pyttsx3
-import pywhatkit
 import datetime
+import pywhatkit
 import wikipedia
 import pyjokes
 from gnewsclient import gnewsclient
 
-__listener = sr.Recognizer()
 __engine = pyttsx3.init()
 __voices = __engine.getProperty("voices")
-__engine.setProperty("voice", __voices[40].id) # 40 is for en_IN, Female voice
-__ext_responses = {}
-__ext_phrases = []
+#print(__voices[1])
+__engine.setProperty("voice", __voices[1].id) # 40 is for en_IN, Female voice
+
+def stop():
+    __engine.stop()
 
 def __listen_all_voices__():
     index = 0
@@ -73,22 +74,24 @@ def speak_single(phrase, debug = True):
     __engine.runAndWait()
 ############# Listening #################
 def listen():
+    r = sr.Recognizer()
     voice_input = ""
     try:
         print("Listening...")
+        r.pause_threshold = 1
         with sr.Microphone() as source:
-            voice = __listener.listen(source)
-            voice_input = __listener.recognize_google(voice)
+            voice = r.listen(source)
+            voice_input = r.recognize_google(voice, language ='en-in')
             voice_input = voice_input.lower()
-    except:
-        print("Error in taking voice input")
+    except Exception as e:
+        print("Error in taking voice input", e)
     return voice_input
 
 ############# Google News #################
 def get_google_news(debug = False):
     client = gnewsclient.NewsClient(language = 'english',
                                     location = 'India',
-                                    max_results=10)
+                                    max_results=3)
     news_to_str = ''
     for news in client.get_news():
         news_to_str += (news['title'] + ".\n")
@@ -159,56 +162,4 @@ def convert_time(utc_time, code, debug = False):
 ############# Playing Song #################
 def play_on_youtube(song):
     speak("playing " + song)
-    pywhatkit.playonyt(song)
-
-############# Custom Response #################
-def save_response(phrase, response, debug = False):
-    global __ext_responses
-    
-    if phrase == None or phrase.strip() == '': 
-        return
-    
-    __ext_responses[phrase.strip()] = response.strip()
-
-
-def __contains_response(phrase, debug = False):
-    global __ext_responses
-
-    if phrase == None or phrase.strip() == '': 
-        return False
-    
-    phrase = phrase.strip()
-    return (phrase in __ext_responses)
-    
-def get_response(phrase, debug = False):
-    global __ext_responses
-
-    if phrase == None or phrase.strip() == '': 
-        return ""
-    
-    phrase = phrase.strip()
-    if __contains_response(phrase, debug):
-        if debug:
-            print("Response: ", __ext_responses[phrase])
-        return __ext_responses[phrase]
-    else:
-        if debug:
-            print("Does not contain phrases")
-        return ""
-
-############# Exit #################
-def add_exit_phrases(phrase):
-    global __ext_phrases
-    
-    __ext_phrases.append(phrase)
-
-def contains_exit_phrase(phrase):
-    global __ext_phrases
-
-    if phrase == None or phrase.strip() == '': 
-        return False
-    
-    phrase = phrase.strip()
-    if phrase in __ext_phrases:
-        return True
-    return False
+    yield pywhatkit.playonyt(song)
